import paho.mqtt.client as mqtt
import time
import json
import schedule

with open("config.json") as file:
    config = json.load(file)

broker_name = config["broker"]
port = config["port"]
topic = config["topic"]
client_id = config["client_id"]
responses = config["responses"]
timer = config["schedule"]

def on_connect(client, userdata, flags, return_code):
    if return_code == 0:
        print("Connected")
    else:
        print("Could not connect, return code:", return_code)


def publish_response(client, topic, response):
    response_json = json.dumps(response)
    result = client.publish(topic, response_json)
    status = result[0]
    if status == 0:
        print("Response published to topic:", topic)
    else:
        print("Failed to send response to topic:", topic)

client = mqtt.Client(client_id)
client.on_connect=on_connect

client.connect(broker_name, port)
client.loop_start()

for response in responses:
    schedule.every(timer).seconds.do(publish_response, client, topic, response)

try:
    while True:
        schedule.run_pending()
        time.sleep(1)
finally:
    client.loop_stop()
